RechnMgmUserArea::UsersController.class_eval do
    if Rails.env != "test"
        after_action :broadcast_role_change, :only => :change_role
    end
    protect_from_forgery :except => [:subscribe_web_push, :unsubscribe_web_push]

    def documents_waiting_for_import
        render :json => { :count => current_user.waiting_documents }
    end

    def set_importing_organisation
        @error   = 0
        @message = "success"

        # First check whether the given id is really the organisation
        organisation = RechnMgmUserArea::Organisation.where(id: importing_organisation_params[:organisation_id]).first

        # try to find the organisation via membership if the membership id was given
        if organisation.nil?
            membership = RechnMgmUserArea::MemberShip.where(id: importing_organisation_params[:organisation_id]).first
            if membership.present?
                organisation = membership.organisation
            end
        end

        if organisation.nil?
            @error = 1
            @message = "Unable to find organisation with id: #{importing_organisation_params[:organisation_id]}"
        else
            current_user.import_for_organisation_id = organisation.id
            unless current_user.save
                @error = 2
                @message = "Unable to save into database: #{current_user.errors[:messages]}"
            end
        end
    end


    def broadcast_role_change
        data = {
            type: :role_change,
            who: current_user.id
        }

        # Send change to all users of the current organisation
        RechnMgmUserArea::MemberShip.where(organisation_id: current_user.current_organisation.id).each do |membership|
            ActionCable.server.broadcast "user_channel_#{membership.user_id}", data
        end
    end

    def subscribe_web_push
        current_user.web_push_user_token = web_push_params[:player_id]
        current_user.save
    end

    def unsubscribe_web_push
        current_user.web_push_user_token = nil if current_user.web_push_user_token == web_push_params[:player_id]
        current_user.save
    end

    private
    def importing_organisation_params
        params.permit(:organisation_id)
    end

    def web_push_params
        params.permit(:player_id)
    end
end
