module RechnMgmWeb
    class ApplicationController < ActionController::Base
        protect_from_forgery with: :exception

        before_action :set_locale
        before_action :set_membership

        NotAuthorised = Class.new(StandardError)

        rescue_from RechnMgmWeb::ApplicationController::NotAuthorised do
            render_error_page(status: 403, text: 'Forbidden')
        end

        def set_locale
            # User locale via ?locale=de param
            I18n.locale = params[:locale] # || I18n.default_locale

            # Use locale from browser of default as fallback
            I18n.locale = extract_locale_from_accept_language_header if I18n.locale.nil?
        end

        private
        def extract_locale_from_accept_language_header
            if ( request.env['HTTP_ACCEPT_LANGUAGE'].nil? )
                return I18n.default_locale
            end
            request.env['HTTP_ACCEPT_LANGUAGE'].scan(/^[a-z]{2}/).first
        end

        def set_membership
            # set membership if organisation was set by the token
            raise RechnMgmWeb::ApplicationController::NotAuthorised if current_user.nil?

            token = Warden::JWTAuth::HeaderParser.from_env(request.headers)
            return if token.nil?

            payload = Warden::JWTAuth::TokenDecoder.new.call(token)
            current_user.current_membership_id = payload["membership_id"]
        end

        def render_error_page(status:, text:, template: 'errors/routing')
            respond_to do |format|
                format.json { render json: {errors: [message: "#{status} #{text}"]}, status: status }
                format.html { redirect_to "/login" } # TODO: Make this smarter (dependent to error status)
                format.any  { head status }
            end
        end
    end
end
