require "rechn_mgm_web/dependencies"
require "rechn_mgm_web/notification_service"

module RechnMgmWeb
    class Engine < ::Rails::Engine
        isolate_namespace RechnMgmWeb

        config.generators do |g|
            g.test_framework :rspec, :fixture => false
            g.fixture_replacement :factory_girl, :dir => 'spec/factories'
            g.assets false
            g.helper false
        end

        config.i18n.default_locale = :de

        # Publish static assets via rails app that integrates this engine. And provide the content of the engines public folder as well.
        initializer "static assets" do |app|
            app.middleware.insert_before(::ActionDispatch::Static, ::ActionDispatch::Static, "#{root}/public")
        end

        # We are decorating other classes in order to add authentication to it.
        initializer :set_decorator_paths, :before => :load_environment_hook do |app|
            ActiveSupportDecorators.debug = true
            ActiveSupportDecorators.paths << File.join(config.root, 'app/**')
        end

        initializer :one_signal, :after => :load_environment_hook do |app|
            OneSignal.configure do |config|
                config.app_id   = Rails.application.config.push_service[:one_signal][:app_id]
                config.api_key  = Rails.application.config.push_service[:one_signal][:api_key]
                config.api_url  = 'https://onesignal.com/api/v1'
                config.active   = true
                config.logger   = Rails.logger # Any Logger compliant implementation
            end
        end

    end
end
